SingleTestSuiteResourceHandler (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server.htmlrunner
Class SingleTestSuiteResourceHandler

    java.lang.Object
      org.mortbay.http.handler.AbstractHttpHandler
          org.mortbay.http.handler.ResourceHandler
              org.openqa.selenium.server.htmlrunner.SingleTestSuiteResourceHandler

All Implemented Interfaces:
  java.io.Serializable, org.mortbay.http.HttpHandler, org.mortbay.util.LifeCycle

    public class SingleTestSuiteResourceHandler

extends org.mortbay.http.handler.ResourceHandler

Generates a test suite table designed to run a single Selenium test; to use it, point TestRunner.html to /singleTest/http://my.com/single/test.html

Author:
  dfabulich
See Also:
  Serialized Form

Constructor Summary
`SingleTestSuiteResourceHandler()`

Method Summary
`void` | `handle(java.lang.String pathInContext, java.lang.String pathParams, org.mortbay.http.HttpRequest request, org.mortbay.http.HttpResponse response)` Handles the HTTP request and generates the suite table

Methods inherited from class org.mortbay.http.handler.ResourceHandler
`getAllowedMethods, getAllowedString, getMinGzipLength, getRedirectWelcome, getResource, handleGet, isAcceptRanges, isDirAllowed, isMethodAllowed, sendData, setAcceptRanges, setAllowedMethods, setDirAllowed, setMinGzipLength, setRedirectWelcome, start, stop, writeHeaders`

Methods inherited from class org.mortbay.http.handler.AbstractHttpHandler
`getHttpContext, getName, handleTrace, initialize, isStarted, setName, toString`

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait`

Constructor Detail

### SingleTestSuiteResourceHandler

    public SingleTestSuiteResourceHandler()

Method Detail

### handle

    public void handle(java.lang.String pathInContext,
                       java.lang.String pathParams,
                       org.mortbay.http.HttpRequest request,
                       org.mortbay.http.HttpResponse response)
                throws org.mortbay.http.HttpException,
                       java.io.IOException

  Handles the HTTP request and generates the suite table

  Specified by:
    `handle` in interface `org.mortbay.http.HttpHandler`
  Overrides:
    `handle` in class `org.mortbay.http.handler.ResourceHandler`
  Throws:
    `org.mortbay.http.HttpException`
    `java.io.IOException`

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.